# gacha-elper

small utility to help automate repetitive tasks in gacha/grinding weaboo games.

## Usage

```python
from src.gacha_elper import GachaElper as Elp
...
```
see `examples`

## License

see [LICENSE](https://github.com/cytopz/gacha-elper/blob/master/LICENSE)
